# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAppElementReferenceParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'update_sketch_info': 'bool',
        'id_tag': 'str',
        'revision': 'str',
        'part_number': 'str',
        'target_version_id': 'str',
        'pure_sketch': 'bool',
        'is_sketch_only': 'bool',
        'target_configuration': 'str',
        'return_error': 'bool',
        'has_document_microversions': 'bool',
        'target_microversion_id': 'str',
        'id_tag_microversion_id': 'str',
        'track_new_versions': 'bool',
        'transaction_id': 'str',
        'parent_change_id': 'str',
        'sketch_id': 'str',
        'sketch_ids': 'list[str]',
        'target_document_id': 'str',
        'target_element_id': 'str'
    }

    attribute_map = {
        'update_sketch_info': 'updateSketchInfo',
        'id_tag': 'idTag',
        'revision': 'revision',
        'part_number': 'partNumber',
        'target_version_id': 'targetVersionId',
        'pure_sketch': 'pureSketch',
        'is_sketch_only': 'isSketchOnly',
        'target_configuration': 'targetConfiguration',
        'return_error': 'returnError',
        'has_document_microversions': 'hasDocumentMicroversions',
        'target_microversion_id': 'targetMicroversionId',
        'id_tag_microversion_id': 'idTagMicroversionId',
        'track_new_versions': 'trackNewVersions',
        'transaction_id': 'transactionId',
        'parent_change_id': 'parentChangeId',
        'sketch_id': 'sketchId',
        'sketch_ids': 'sketchIds',
        'target_document_id': 'targetDocumentId',
        'target_element_id': 'targetElementId'
    }

    def __init__(self, update_sketch_info=None, id_tag=None, revision=None, part_number=None, target_version_id=None, pure_sketch=None, is_sketch_only=None, target_configuration=None, return_error=None, has_document_microversions=None, target_microversion_id=None, id_tag_microversion_id=None, track_new_versions=None, transaction_id=None, parent_change_id=None, sketch_id=None, sketch_ids=None, target_document_id=None, target_element_id=None):  # noqa: E501
        """BTAppElementReferenceParams - a model defined in OpenAPI"""  # noqa: E501

        self._update_sketch_info = None
        self._id_tag = None
        self._revision = None
        self._part_number = None
        self._target_version_id = None
        self._pure_sketch = None
        self._is_sketch_only = None
        self._target_configuration = None
        self._return_error = None
        self._has_document_microversions = None
        self._target_microversion_id = None
        self._id_tag_microversion_id = None
        self._track_new_versions = None
        self._transaction_id = None
        self._parent_change_id = None
        self._sketch_id = None
        self._sketch_ids = None
        self._target_document_id = None
        self._target_element_id = None
        self.discriminator = None

        if update_sketch_info is not None:
            self.update_sketch_info = update_sketch_info
        if id_tag is not None:
            self.id_tag = id_tag
        if revision is not None:
            self.revision = revision
        if part_number is not None:
            self.part_number = part_number
        if target_version_id is not None:
            self.target_version_id = target_version_id
        if pure_sketch is not None:
            self.pure_sketch = pure_sketch
        if is_sketch_only is not None:
            self.is_sketch_only = is_sketch_only
        if target_configuration is not None:
            self.target_configuration = target_configuration
        if return_error is not None:
            self.return_error = return_error
        if has_document_microversions is not None:
            self.has_document_microversions = has_document_microversions
        if target_microversion_id is not None:
            self.target_microversion_id = target_microversion_id
        if id_tag_microversion_id is not None:
            self.id_tag_microversion_id = id_tag_microversion_id
        if track_new_versions is not None:
            self.track_new_versions = track_new_versions
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if parent_change_id is not None:
            self.parent_change_id = parent_change_id
        if sketch_id is not None:
            self.sketch_id = sketch_id
        if sketch_ids is not None:
            self.sketch_ids = sketch_ids
        if target_document_id is not None:
            self.target_document_id = target_document_id
        if target_element_id is not None:
            self.target_element_id = target_element_id

    @property
    def update_sketch_info(self):
        """Gets the update_sketch_info of this BTAppElementReferenceParams.  # noqa: E501


        :return: The update_sketch_info of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: bool
        """
        return self._update_sketch_info

    @update_sketch_info.setter
    def update_sketch_info(self, update_sketch_info):
        """Sets the update_sketch_info of this BTAppElementReferenceParams.


        :param update_sketch_info: The update_sketch_info of this BTAppElementReferenceParams.  # noqa: E501
        :type: bool
        """

        self._update_sketch_info = update_sketch_info

    @property
    def id_tag(self):
        """Gets the id_tag of this BTAppElementReferenceParams.  # noqa: E501


        :return: The id_tag of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._id_tag

    @id_tag.setter
    def id_tag(self, id_tag):
        """Sets the id_tag of this BTAppElementReferenceParams.


        :param id_tag: The id_tag of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._id_tag = id_tag

    @property
    def revision(self):
        """Gets the revision of this BTAppElementReferenceParams.  # noqa: E501


        :return: The revision of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this BTAppElementReferenceParams.


        :param revision: The revision of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def part_number(self):
        """Gets the part_number of this BTAppElementReferenceParams.  # noqa: E501


        :return: The part_number of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this BTAppElementReferenceParams.


        :param part_number: The part_number of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def target_version_id(self):
        """Gets the target_version_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The target_version_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._target_version_id

    @target_version_id.setter
    def target_version_id(self, target_version_id):
        """Sets the target_version_id of this BTAppElementReferenceParams.


        :param target_version_id: The target_version_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._target_version_id = target_version_id

    @property
    def pure_sketch(self):
        """Gets the pure_sketch of this BTAppElementReferenceParams.  # noqa: E501


        :return: The pure_sketch of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: bool
        """
        return self._pure_sketch

    @pure_sketch.setter
    def pure_sketch(self, pure_sketch):
        """Sets the pure_sketch of this BTAppElementReferenceParams.


        :param pure_sketch: The pure_sketch of this BTAppElementReferenceParams.  # noqa: E501
        :type: bool
        """

        self._pure_sketch = pure_sketch

    @property
    def is_sketch_only(self):
        """Gets the is_sketch_only of this BTAppElementReferenceParams.  # noqa: E501


        :return: The is_sketch_only of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_sketch_only

    @is_sketch_only.setter
    def is_sketch_only(self, is_sketch_only):
        """Sets the is_sketch_only of this BTAppElementReferenceParams.


        :param is_sketch_only: The is_sketch_only of this BTAppElementReferenceParams.  # noqa: E501
        :type: bool
        """

        self._is_sketch_only = is_sketch_only

    @property
    def target_configuration(self):
        """Gets the target_configuration of this BTAppElementReferenceParams.  # noqa: E501


        :return: The target_configuration of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._target_configuration

    @target_configuration.setter
    def target_configuration(self, target_configuration):
        """Sets the target_configuration of this BTAppElementReferenceParams.


        :param target_configuration: The target_configuration of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._target_configuration = target_configuration

    @property
    def return_error(self):
        """Gets the return_error of this BTAppElementReferenceParams.  # noqa: E501


        :return: The return_error of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: bool
        """
        return self._return_error

    @return_error.setter
    def return_error(self, return_error):
        """Sets the return_error of this BTAppElementReferenceParams.


        :param return_error: The return_error of this BTAppElementReferenceParams.  # noqa: E501
        :type: bool
        """

        self._return_error = return_error

    @property
    def has_document_microversions(self):
        """Gets the has_document_microversions of this BTAppElementReferenceParams.  # noqa: E501


        :return: The has_document_microversions of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: bool
        """
        return self._has_document_microversions

    @has_document_microversions.setter
    def has_document_microversions(self, has_document_microversions):
        """Sets the has_document_microversions of this BTAppElementReferenceParams.


        :param has_document_microversions: The has_document_microversions of this BTAppElementReferenceParams.  # noqa: E501
        :type: bool
        """

        self._has_document_microversions = has_document_microversions

    @property
    def target_microversion_id(self):
        """Gets the target_microversion_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The target_microversion_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._target_microversion_id

    @target_microversion_id.setter
    def target_microversion_id(self, target_microversion_id):
        """Sets the target_microversion_id of this BTAppElementReferenceParams.


        :param target_microversion_id: The target_microversion_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._target_microversion_id = target_microversion_id

    @property
    def id_tag_microversion_id(self):
        """Gets the id_tag_microversion_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The id_tag_microversion_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._id_tag_microversion_id

    @id_tag_microversion_id.setter
    def id_tag_microversion_id(self, id_tag_microversion_id):
        """Sets the id_tag_microversion_id of this BTAppElementReferenceParams.


        :param id_tag_microversion_id: The id_tag_microversion_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._id_tag_microversion_id = id_tag_microversion_id

    @property
    def track_new_versions(self):
        """Gets the track_new_versions of this BTAppElementReferenceParams.  # noqa: E501


        :return: The track_new_versions of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: bool
        """
        return self._track_new_versions

    @track_new_versions.setter
    def track_new_versions(self, track_new_versions):
        """Sets the track_new_versions of this BTAppElementReferenceParams.


        :param track_new_versions: The track_new_versions of this BTAppElementReferenceParams.  # noqa: E501
        :type: bool
        """

        self._track_new_versions = track_new_versions

    @property
    def transaction_id(self):
        """Gets the transaction_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The transaction_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this BTAppElementReferenceParams.


        :param transaction_id: The transaction_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def parent_change_id(self):
        """Gets the parent_change_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The parent_change_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_change_id

    @parent_change_id.setter
    def parent_change_id(self, parent_change_id):
        """Sets the parent_change_id of this BTAppElementReferenceParams.


        :param parent_change_id: The parent_change_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._parent_change_id = parent_change_id

    @property
    def sketch_id(self):
        """Gets the sketch_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The sketch_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._sketch_id

    @sketch_id.setter
    def sketch_id(self, sketch_id):
        """Sets the sketch_id of this BTAppElementReferenceParams.


        :param sketch_id: The sketch_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._sketch_id = sketch_id

    @property
    def sketch_ids(self):
        """Gets the sketch_ids of this BTAppElementReferenceParams.  # noqa: E501


        :return: The sketch_ids of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._sketch_ids

    @sketch_ids.setter
    def sketch_ids(self, sketch_ids):
        """Sets the sketch_ids of this BTAppElementReferenceParams.


        :param sketch_ids: The sketch_ids of this BTAppElementReferenceParams.  # noqa: E501
        :type: list[str]
        """

        self._sketch_ids = sketch_ids

    @property
    def target_document_id(self):
        """Gets the target_document_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The target_document_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._target_document_id

    @target_document_id.setter
    def target_document_id(self, target_document_id):
        """Sets the target_document_id of this BTAppElementReferenceParams.


        :param target_document_id: The target_document_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._target_document_id = target_document_id

    @property
    def target_element_id(self):
        """Gets the target_element_id of this BTAppElementReferenceParams.  # noqa: E501


        :return: The target_element_id of this BTAppElementReferenceParams.  # noqa: E501
        :rtype: str
        """
        return self._target_element_id

    @target_element_id.setter
    def target_element_id(self, target_element_id):
        """Sets the target_element_id of this BTAppElementReferenceParams.


        :param target_element_id: The target_element_id of this BTAppElementReferenceParams.  # noqa: E501
        :type: str
        """

        self._target_element_id = target_element_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAppElementReferenceParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBillingAccountParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'BTAddressInfo',
        'force_create': 'bool',
        'password': 'str',
        'trial_period_days': 'int',
        'user_id': 'str',
        'token': 'str',
        'plan_id': 'str',
        'company_id': 'str',
        'seats': 'int',
        'domain_prefix': 'str',
        'company_plan': 'bool',
        'promonthly_enabled': 'bool',
        'company_name': 'str',
        'payment_type': 'int',
        'reseller_name': 'str'
    }

    attribute_map = {
        'address': 'address',
        'force_create': 'forceCreate',
        'password': 'password',
        'trial_period_days': 'trialPeriodDays',
        'user_id': 'userId',
        'token': 'token',
        'plan_id': 'planId',
        'company_id': 'companyId',
        'seats': 'seats',
        'domain_prefix': 'domainPrefix',
        'company_plan': 'companyPlan',
        'promonthly_enabled': 'promonthlyEnabled',
        'company_name': 'companyName',
        'payment_type': 'paymentType',
        'reseller_name': 'resellerName'
    }

    def __init__(self, address=None, force_create=None, password=None, trial_period_days=None, user_id=None, token=None, plan_id=None, company_id=None, seats=None, domain_prefix=None, company_plan=None, promonthly_enabled=None, company_name=None, payment_type=None, reseller_name=None):  # noqa: E501
        """BTBillingAccountParams - a model defined in OpenAPI"""  # noqa: E501

        self._address = None
        self._force_create = None
        self._password = None
        self._trial_period_days = None
        self._user_id = None
        self._token = None
        self._plan_id = None
        self._company_id = None
        self._seats = None
        self._domain_prefix = None
        self._company_plan = None
        self._promonthly_enabled = None
        self._company_name = None
        self._payment_type = None
        self._reseller_name = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if force_create is not None:
            self.force_create = force_create
        if password is not None:
            self.password = password
        if trial_period_days is not None:
            self.trial_period_days = trial_period_days
        if user_id is not None:
            self.user_id = user_id
        if token is not None:
            self.token = token
        if plan_id is not None:
            self.plan_id = plan_id
        if company_id is not None:
            self.company_id = company_id
        if seats is not None:
            self.seats = seats
        if domain_prefix is not None:
            self.domain_prefix = domain_prefix
        if company_plan is not None:
            self.company_plan = company_plan
        if promonthly_enabled is not None:
            self.promonthly_enabled = promonthly_enabled
        if company_name is not None:
            self.company_name = company_name
        if payment_type is not None:
            self.payment_type = payment_type
        if reseller_name is not None:
            self.reseller_name = reseller_name

    @property
    def address(self):
        """Gets the address of this BTBillingAccountParams.  # noqa: E501


        :return: The address of this BTBillingAccountParams.  # noqa: E501
        :rtype: BTAddressInfo
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this BTBillingAccountParams.


        :param address: The address of this BTBillingAccountParams.  # noqa: E501
        :type: BTAddressInfo
        """

        self._address = address

    @property
    def force_create(self):
        """Gets the force_create of this BTBillingAccountParams.  # noqa: E501


        :return: The force_create of this BTBillingAccountParams.  # noqa: E501
        :rtype: bool
        """
        return self._force_create

    @force_create.setter
    def force_create(self, force_create):
        """Sets the force_create of this BTBillingAccountParams.


        :param force_create: The force_create of this BTBillingAccountParams.  # noqa: E501
        :type: bool
        """

        self._force_create = force_create

    @property
    def password(self):
        """Gets the password of this BTBillingAccountParams.  # noqa: E501


        :return: The password of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this BTBillingAccountParams.


        :param password: The password of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def trial_period_days(self):
        """Gets the trial_period_days of this BTBillingAccountParams.  # noqa: E501


        :return: The trial_period_days of this BTBillingAccountParams.  # noqa: E501
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """Sets the trial_period_days of this BTBillingAccountParams.


        :param trial_period_days: The trial_period_days of this BTBillingAccountParams.  # noqa: E501
        :type: int
        """

        self._trial_period_days = trial_period_days

    @property
    def user_id(self):
        """Gets the user_id of this BTBillingAccountParams.  # noqa: E501


        :return: The user_id of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BTBillingAccountParams.


        :param user_id: The user_id of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def token(self):
        """Gets the token of this BTBillingAccountParams.  # noqa: E501


        :return: The token of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this BTBillingAccountParams.


        :param token: The token of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def plan_id(self):
        """Gets the plan_id of this BTBillingAccountParams.  # noqa: E501


        :return: The plan_id of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTBillingAccountParams.


        :param plan_id: The plan_id of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def company_id(self):
        """Gets the company_id of this BTBillingAccountParams.  # noqa: E501


        :return: The company_id of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this BTBillingAccountParams.


        :param company_id: The company_id of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def seats(self):
        """Gets the seats of this BTBillingAccountParams.  # noqa: E501


        :return: The seats of this BTBillingAccountParams.  # noqa: E501
        :rtype: int
        """
        return self._seats

    @seats.setter
    def seats(self, seats):
        """Sets the seats of this BTBillingAccountParams.


        :param seats: The seats of this BTBillingAccountParams.  # noqa: E501
        :type: int
        """

        self._seats = seats

    @property
    def domain_prefix(self):
        """Gets the domain_prefix of this BTBillingAccountParams.  # noqa: E501


        :return: The domain_prefix of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._domain_prefix

    @domain_prefix.setter
    def domain_prefix(self, domain_prefix):
        """Sets the domain_prefix of this BTBillingAccountParams.


        :param domain_prefix: The domain_prefix of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._domain_prefix = domain_prefix

    @property
    def company_plan(self):
        """Gets the company_plan of this BTBillingAccountParams.  # noqa: E501


        :return: The company_plan of this BTBillingAccountParams.  # noqa: E501
        :rtype: bool
        """
        return self._company_plan

    @company_plan.setter
    def company_plan(self, company_plan):
        """Sets the company_plan of this BTBillingAccountParams.


        :param company_plan: The company_plan of this BTBillingAccountParams.  # noqa: E501
        :type: bool
        """

        self._company_plan = company_plan

    @property
    def promonthly_enabled(self):
        """Gets the promonthly_enabled of this BTBillingAccountParams.  # noqa: E501


        :return: The promonthly_enabled of this BTBillingAccountParams.  # noqa: E501
        :rtype: bool
        """
        return self._promonthly_enabled

    @promonthly_enabled.setter
    def promonthly_enabled(self, promonthly_enabled):
        """Sets the promonthly_enabled of this BTBillingAccountParams.


        :param promonthly_enabled: The promonthly_enabled of this BTBillingAccountParams.  # noqa: E501
        :type: bool
        """

        self._promonthly_enabled = promonthly_enabled

    @property
    def company_name(self):
        """Gets the company_name of this BTBillingAccountParams.  # noqa: E501


        :return: The company_name of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this BTBillingAccountParams.


        :param company_name: The company_name of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def payment_type(self):
        """Gets the payment_type of this BTBillingAccountParams.  # noqa: E501


        :return: The payment_type of this BTBillingAccountParams.  # noqa: E501
        :rtype: int
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this BTBillingAccountParams.


        :param payment_type: The payment_type of this BTBillingAccountParams.  # noqa: E501
        :type: int
        """

        self._payment_type = payment_type

    @property
    def reseller_name(self):
        """Gets the reseller_name of this BTBillingAccountParams.  # noqa: E501


        :return: The reseller_name of this BTBillingAccountParams.  # noqa: E501
        :rtype: str
        """
        return self._reseller_name

    @reseller_name.setter
    def reseller_name(self, reseller_name):
        """Sets the reseller_name of this BTBillingAccountParams.


        :param reseller_name: The reseller_name of this BTBillingAccountParams.  # noqa: E501
        :type: str
        """

        self._reseller_name = reseller_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBillingAccountParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTInAppMessageContentItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content_id': 'str',
        'title': 'str',
        'template': 'str',
        'thumbnail': 'str',
        'link': 'str',
        'height': 'int',
        'width': 'int',
        'player': 'str',
        'pause_points': 'list[float]',
        'position': 'str',
        'item_title': 'str',
        'vertical_offset': 'int',
        'horizontal_offset': 'int',
        'anchor': 'str'
    }

    attribute_map = {
        'content_id': 'contentId',
        'title': 'title',
        'template': 'template',
        'thumbnail': 'thumbnail',
        'link': 'link',
        'height': 'height',
        'width': 'width',
        'player': 'player',
        'pause_points': 'pausePoints',
        'position': 'position',
        'item_title': 'itemTitle',
        'vertical_offset': 'verticalOffset',
        'horizontal_offset': 'horizontalOffset',
        'anchor': 'anchor'
    }

    def __init__(self, content_id=None, title=None, template=None, thumbnail=None, link=None, height=None, width=None, player=None, pause_points=None, position=None, item_title=None, vertical_offset=None, horizontal_offset=None, anchor=None):  # noqa: E501
        """BTInAppMessageContentItem - a model defined in OpenAPI"""  # noqa: E501

        self._content_id = None
        self._title = None
        self._template = None
        self._thumbnail = None
        self._link = None
        self._height = None
        self._width = None
        self._player = None
        self._pause_points = None
        self._position = None
        self._item_title = None
        self._vertical_offset = None
        self._horizontal_offset = None
        self._anchor = None
        self.discriminator = None

        if content_id is not None:
            self.content_id = content_id
        if title is not None:
            self.title = title
        if template is not None:
            self.template = template
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if link is not None:
            self.link = link
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if player is not None:
            self.player = player
        if pause_points is not None:
            self.pause_points = pause_points
        if position is not None:
            self.position = position
        if item_title is not None:
            self.item_title = item_title
        if vertical_offset is not None:
            self.vertical_offset = vertical_offset
        if horizontal_offset is not None:
            self.horizontal_offset = horizontal_offset
        if anchor is not None:
            self.anchor = anchor

    @property
    def content_id(self):
        """Gets the content_id of this BTInAppMessageContentItem.  # noqa: E501


        :return: The content_id of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        """Sets the content_id of this BTInAppMessageContentItem.


        :param content_id: The content_id of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._content_id = content_id

    @property
    def title(self):
        """Gets the title of this BTInAppMessageContentItem.  # noqa: E501


        :return: The title of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BTInAppMessageContentItem.


        :param title: The title of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def template(self):
        """Gets the template of this BTInAppMessageContentItem.  # noqa: E501


        :return: The template of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this BTInAppMessageContentItem.


        :param template: The template of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._template = template

    @property
    def thumbnail(self):
        """Gets the thumbnail of this BTInAppMessageContentItem.  # noqa: E501


        :return: The thumbnail of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this BTInAppMessageContentItem.


        :param thumbnail: The thumbnail of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._thumbnail = thumbnail

    @property
    def link(self):
        """Gets the link of this BTInAppMessageContentItem.  # noqa: E501


        :return: The link of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this BTInAppMessageContentItem.


        :param link: The link of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._link = link

    @property
    def height(self):
        """Gets the height of this BTInAppMessageContentItem.  # noqa: E501


        :return: The height of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this BTInAppMessageContentItem.


        :param height: The height of this BTInAppMessageContentItem.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def width(self):
        """Gets the width of this BTInAppMessageContentItem.  # noqa: E501


        :return: The width of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this BTInAppMessageContentItem.


        :param width: The width of this BTInAppMessageContentItem.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def player(self):
        """Gets the player of this BTInAppMessageContentItem.  # noqa: E501


        :return: The player of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._player

    @player.setter
    def player(self, player):
        """Sets the player of this BTInAppMessageContentItem.


        :param player: The player of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._player = player

    @property
    def pause_points(self):
        """Gets the pause_points of this BTInAppMessageContentItem.  # noqa: E501


        :return: The pause_points of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: list[float]
        """
        return self._pause_points

    @pause_points.setter
    def pause_points(self, pause_points):
        """Sets the pause_points of this BTInAppMessageContentItem.


        :param pause_points: The pause_points of this BTInAppMessageContentItem.  # noqa: E501
        :type: list[float]
        """

        self._pause_points = pause_points

    @property
    def position(self):
        """Gets the position of this BTInAppMessageContentItem.  # noqa: E501


        :return: The position of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this BTInAppMessageContentItem.


        :param position: The position of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def item_title(self):
        """Gets the item_title of this BTInAppMessageContentItem.  # noqa: E501


        :return: The item_title of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._item_title

    @item_title.setter
    def item_title(self, item_title):
        """Sets the item_title of this BTInAppMessageContentItem.


        :param item_title: The item_title of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._item_title = item_title

    @property
    def vertical_offset(self):
        """Gets the vertical_offset of this BTInAppMessageContentItem.  # noqa: E501


        :return: The vertical_offset of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: int
        """
        return self._vertical_offset

    @vertical_offset.setter
    def vertical_offset(self, vertical_offset):
        """Sets the vertical_offset of this BTInAppMessageContentItem.


        :param vertical_offset: The vertical_offset of this BTInAppMessageContentItem.  # noqa: E501
        :type: int
        """

        self._vertical_offset = vertical_offset

    @property
    def horizontal_offset(self):
        """Gets the horizontal_offset of this BTInAppMessageContentItem.  # noqa: E501


        :return: The horizontal_offset of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: int
        """
        return self._horizontal_offset

    @horizontal_offset.setter
    def horizontal_offset(self, horizontal_offset):
        """Sets the horizontal_offset of this BTInAppMessageContentItem.


        :param horizontal_offset: The horizontal_offset of this BTInAppMessageContentItem.  # noqa: E501
        :type: int
        """

        self._horizontal_offset = horizontal_offset

    @property
    def anchor(self):
        """Gets the anchor of this BTInAppMessageContentItem.  # noqa: E501


        :return: The anchor of this BTInAppMessageContentItem.  # noqa: E501
        :rtype: str
        """
        return self._anchor

    @anchor.setter
    def anchor(self, anchor):
        """Sets the anchor of this BTInAppMessageContentItem.


        :param anchor: The anchor of this BTInAppMessageContentItem.  # noqa: E501
        :type: str
        """

        self._anchor = anchor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTInAppMessageContentItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTLoginParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email': 'str',
        'password': 'str',
        'device_id': 'str',
        'random_token': 'str',
        'totp': 'str',
        'remember_totp': 'bool',
        'web_client_capabilities': 'BTWebClientCapabilitiesParams',
        'enable_totp': 'bool',
        'renderer_performance_measurement': 'BTWebRendererPerformanceMeasurementParams'
    }

    attribute_map = {
        'email': 'email',
        'password': 'password',
        'device_id': 'deviceId',
        'random_token': 'randomToken',
        'totp': 'totp',
        'remember_totp': 'rememberTotp',
        'web_client_capabilities': 'webClientCapabilities',
        'enable_totp': 'enableTotp',
        'renderer_performance_measurement': 'rendererPerformanceMeasurement'
    }

    def __init__(self, email=None, password=None, device_id=None, random_token=None, totp=None, remember_totp=None, web_client_capabilities=None, enable_totp=None, renderer_performance_measurement=None):  # noqa: E501
        """BTLoginParams - a model defined in OpenAPI"""  # noqa: E501

        self._email = None
        self._password = None
        self._device_id = None
        self._random_token = None
        self._totp = None
        self._remember_totp = None
        self._web_client_capabilities = None
        self._enable_totp = None
        self._renderer_performance_measurement = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if password is not None:
            self.password = password
        if device_id is not None:
            self.device_id = device_id
        if random_token is not None:
            self.random_token = random_token
        if totp is not None:
            self.totp = totp
        if remember_totp is not None:
            self.remember_totp = remember_totp
        if web_client_capabilities is not None:
            self.web_client_capabilities = web_client_capabilities
        if enable_totp is not None:
            self.enable_totp = enable_totp
        if renderer_performance_measurement is not None:
            self.renderer_performance_measurement = renderer_performance_measurement

    @property
    def email(self):
        """Gets the email of this BTLoginParams.  # noqa: E501


        :return: The email of this BTLoginParams.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTLoginParams.


        :param email: The email of this BTLoginParams.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def password(self):
        """Gets the password of this BTLoginParams.  # noqa: E501


        :return: The password of this BTLoginParams.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this BTLoginParams.


        :param password: The password of this BTLoginParams.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def device_id(self):
        """Gets the device_id of this BTLoginParams.  # noqa: E501


        :return: The device_id of this BTLoginParams.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this BTLoginParams.


        :param device_id: The device_id of this BTLoginParams.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def random_token(self):
        """Gets the random_token of this BTLoginParams.  # noqa: E501


        :return: The random_token of this BTLoginParams.  # noqa: E501
        :rtype: str
        """
        return self._random_token

    @random_token.setter
    def random_token(self, random_token):
        """Sets the random_token of this BTLoginParams.


        :param random_token: The random_token of this BTLoginParams.  # noqa: E501
        :type: str
        """

        self._random_token = random_token

    @property
    def totp(self):
        """Gets the totp of this BTLoginParams.  # noqa: E501


        :return: The totp of this BTLoginParams.  # noqa: E501
        :rtype: str
        """
        return self._totp

    @totp.setter
    def totp(self, totp):
        """Sets the totp of this BTLoginParams.


        :param totp: The totp of this BTLoginParams.  # noqa: E501
        :type: str
        """

        self._totp = totp

    @property
    def remember_totp(self):
        """Gets the remember_totp of this BTLoginParams.  # noqa: E501


        :return: The remember_totp of this BTLoginParams.  # noqa: E501
        :rtype: bool
        """
        return self._remember_totp

    @remember_totp.setter
    def remember_totp(self, remember_totp):
        """Sets the remember_totp of this BTLoginParams.


        :param remember_totp: The remember_totp of this BTLoginParams.  # noqa: E501
        :type: bool
        """

        self._remember_totp = remember_totp

    @property
    def web_client_capabilities(self):
        """Gets the web_client_capabilities of this BTLoginParams.  # noqa: E501


        :return: The web_client_capabilities of this BTLoginParams.  # noqa: E501
        :rtype: BTWebClientCapabilitiesParams
        """
        return self._web_client_capabilities

    @web_client_capabilities.setter
    def web_client_capabilities(self, web_client_capabilities):
        """Sets the web_client_capabilities of this BTLoginParams.


        :param web_client_capabilities: The web_client_capabilities of this BTLoginParams.  # noqa: E501
        :type: BTWebClientCapabilitiesParams
        """

        self._web_client_capabilities = web_client_capabilities

    @property
    def enable_totp(self):
        """Gets the enable_totp of this BTLoginParams.  # noqa: E501


        :return: The enable_totp of this BTLoginParams.  # noqa: E501
        :rtype: bool
        """
        return self._enable_totp

    @enable_totp.setter
    def enable_totp(self, enable_totp):
        """Sets the enable_totp of this BTLoginParams.


        :param enable_totp: The enable_totp of this BTLoginParams.  # noqa: E501
        :type: bool
        """

        self._enable_totp = enable_totp

    @property
    def renderer_performance_measurement(self):
        """Gets the renderer_performance_measurement of this BTLoginParams.  # noqa: E501


        :return: The renderer_performance_measurement of this BTLoginParams.  # noqa: E501
        :rtype: BTWebRendererPerformanceMeasurementParams
        """
        return self._renderer_performance_measurement

    @renderer_performance_measurement.setter
    def renderer_performance_measurement(self, renderer_performance_measurement):
        """Sets the renderer_performance_measurement of this BTLoginParams.


        :param renderer_performance_measurement: The renderer_performance_measurement of this BTLoginParams.  # noqa: E501
        :type: BTWebRendererPerformanceMeasurementParams
        """

        self._renderer_performance_measurement = renderer_performance_measurement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTLoginParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTThumbnailSizeInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'size': 'str',
        'sheet_name': 'str',
        'href': 'str',
        'unique_id': 'str',
        'media_type': 'str',
        'view_orientation': 'str',
        'render_mode': 'str'
    }

    attribute_map = {
        'size': 'size',
        'sheet_name': 'sheetName',
        'href': 'href',
        'unique_id': 'uniqueId',
        'media_type': 'mediaType',
        'view_orientation': 'viewOrientation',
        'render_mode': 'renderMode'
    }

    def __init__(self, size=None, sheet_name=None, href=None, unique_id=None, media_type=None, view_orientation=None, render_mode=None):  # noqa: E501
        """BTThumbnailSizeInfo - a model defined in OpenAPI"""  # noqa: E501

        self._size = None
        self._sheet_name = None
        self._href = None
        self._unique_id = None
        self._media_type = None
        self._view_orientation = None
        self._render_mode = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if sheet_name is not None:
            self.sheet_name = sheet_name
        if href is not None:
            self.href = href
        if unique_id is not None:
            self.unique_id = unique_id
        if media_type is not None:
            self.media_type = media_type
        if view_orientation is not None:
            self.view_orientation = view_orientation
        if render_mode is not None:
            self.render_mode = render_mode

    @property
    def size(self):
        """Gets the size of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The size of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this BTThumbnailSizeInfo.


        :param size: The size of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def sheet_name(self):
        """Gets the sheet_name of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The sheet_name of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._sheet_name

    @sheet_name.setter
    def sheet_name(self, sheet_name):
        """Sets the sheet_name of this BTThumbnailSizeInfo.


        :param sheet_name: The sheet_name of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._sheet_name = sheet_name

    @property
    def href(self):
        """Gets the href of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The href of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTThumbnailSizeInfo.


        :param href: The href of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def unique_id(self):
        """Gets the unique_id of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The unique_id of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._unique_id

    @unique_id.setter
    def unique_id(self, unique_id):
        """Sets the unique_id of this BTThumbnailSizeInfo.


        :param unique_id: The unique_id of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._unique_id = unique_id

    @property
    def media_type(self):
        """Gets the media_type of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The media_type of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """Sets the media_type of this BTThumbnailSizeInfo.


        :param media_type: The media_type of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._media_type = media_type

    @property
    def view_orientation(self):
        """Gets the view_orientation of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The view_orientation of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_orientation

    @view_orientation.setter
    def view_orientation(self, view_orientation):
        """Sets the view_orientation of this BTThumbnailSizeInfo.


        :param view_orientation: The view_orientation of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._view_orientation = view_orientation

    @property
    def render_mode(self):
        """Gets the render_mode of this BTThumbnailSizeInfo.  # noqa: E501


        :return: The render_mode of this BTThumbnailSizeInfo.  # noqa: E501
        :rtype: str
        """
        return self._render_mode

    @render_mode.setter
    def render_mode(self, render_mode):
        """Sets the render_mode of this BTThumbnailSizeInfo.


        :param render_mode: The render_mode of this BTThumbnailSizeInfo.  # noqa: E501
        :type: str
        """

        self._render_mode = render_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTThumbnailSizeInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAppViewParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parameters': 'list[float]',
        'crop_view': 'bool',
        'include_hidden_instances': 'bool',
        'view_scale': 'float',
        'show_tangent_lines': 'bool',
        'compute_intersection': 'bool',
        'is_broken_out_section': 'bool',
        'is_crop_view': 'bool',
        'hidden_lines': 'str',
        'modification_id': 'str',
        'perspective': 'bool',
        'projection_angle': 'str',
        'show_threads': 'bool',
        'is_partial_section': 'bool',
        'broken_out_point_numbers': 'list[int]',
        'broken_out_end_conditions': 'dict(str, BTBrokenOutEndCondition)',
        'broken_out_b_boxes': 'list[float]',
        'broken_out_b_boxes_map': 'dict(str, BTBoundingBox)',
        'include_surfaces': 'bool',
        'is_surface': 'bool',
        'depth_section_end_condition': 'BTBrokenOutEndCondition',
        'display_state_id': 'str',
        'transaction_id': 'str',
        'parent_change_id': 'str',
        'model_reference_id': 'str',
        'view_matrix': 'list[float]',
        'view_direction': 'list[float]',
        'cut_point': 'list[float]',
        'offset_section_points': 'list[float]',
        'broken_out_section': 'bool',
        'bom_reference_id': 'str',
        'occurrence_or_part_id_to_geometry_properties': 'dict(str, dict(str, str))'
    }

    attribute_map = {
        'parameters': 'parameters',
        'crop_view': 'cropView',
        'include_hidden_instances': 'includeHiddenInstances',
        'view_scale': 'viewScale',
        'show_tangent_lines': 'showTangentLines',
        'compute_intersection': 'computeIntersection',
        'is_broken_out_section': 'isBrokenOutSection',
        'is_crop_view': 'isCropView',
        'hidden_lines': 'hiddenLines',
        'modification_id': 'modificationId',
        'perspective': 'perspective',
        'projection_angle': 'projectionAngle',
        'show_threads': 'showThreads',
        'is_partial_section': 'isPartialSection',
        'broken_out_point_numbers': 'brokenOutPointNumbers',
        'broken_out_end_conditions': 'brokenOutEndConditions',
        'broken_out_b_boxes': 'brokenOutBBoxes',
        'broken_out_b_boxes_map': 'brokenOutBBoxesMap',
        'include_surfaces': 'includeSurfaces',
        'is_surface': 'isSurface',
        'depth_section_end_condition': 'depthSectionEndCondition',
        'display_state_id': 'displayStateId',
        'transaction_id': 'transactionId',
        'parent_change_id': 'parentChangeId',
        'model_reference_id': 'modelReferenceId',
        'view_matrix': 'viewMatrix',
        'view_direction': 'viewDirection',
        'cut_point': 'cutPoint',
        'offset_section_points': 'offsetSectionPoints',
        'broken_out_section': 'brokenOutSection',
        'bom_reference_id': 'bomReferenceId',
        'occurrence_or_part_id_to_geometry_properties': 'occurrenceOrPartIdToGeometryProperties'
    }

    def __init__(self, parameters=None, crop_view=None, include_hidden_instances=None, view_scale=None, show_tangent_lines=None, compute_intersection=None, is_broken_out_section=None, is_crop_view=None, hidden_lines=None, modification_id=None, perspective=None, projection_angle=None, show_threads=None, is_partial_section=None, broken_out_point_numbers=None, broken_out_end_conditions=None, broken_out_b_boxes=None, broken_out_b_boxes_map=None, include_surfaces=None, is_surface=None, depth_section_end_condition=None, display_state_id=None, transaction_id=None, parent_change_id=None, model_reference_id=None, view_matrix=None, view_direction=None, cut_point=None, offset_section_points=None, broken_out_section=None, bom_reference_id=None, occurrence_or_part_id_to_geometry_properties=None):  # noqa: E501
        """BTAppViewParams - a model defined in OpenAPI"""  # noqa: E501

        self._parameters = None
        self._crop_view = None
        self._include_hidden_instances = None
        self._view_scale = None
        self._show_tangent_lines = None
        self._compute_intersection = None
        self._is_broken_out_section = None
        self._is_crop_view = None
        self._hidden_lines = None
        self._modification_id = None
        self._perspective = None
        self._projection_angle = None
        self._show_threads = None
        self._is_partial_section = None
        self._broken_out_point_numbers = None
        self._broken_out_end_conditions = None
        self._broken_out_b_boxes = None
        self._broken_out_b_boxes_map = None
        self._include_surfaces = None
        self._is_surface = None
        self._depth_section_end_condition = None
        self._display_state_id = None
        self._transaction_id = None
        self._parent_change_id = None
        self._model_reference_id = None
        self._view_matrix = None
        self._view_direction = None
        self._cut_point = None
        self._offset_section_points = None
        self._broken_out_section = None
        self._bom_reference_id = None
        self._occurrence_or_part_id_to_geometry_properties = None
        self.discriminator = None

        if parameters is not None:
            self.parameters = parameters
        if crop_view is not None:
            self.crop_view = crop_view
        if include_hidden_instances is not None:
            self.include_hidden_instances = include_hidden_instances
        if view_scale is not None:
            self.view_scale = view_scale
        if show_tangent_lines is not None:
            self.show_tangent_lines = show_tangent_lines
        if compute_intersection is not None:
            self.compute_intersection = compute_intersection
        if is_broken_out_section is not None:
            self.is_broken_out_section = is_broken_out_section
        if is_crop_view is not None:
            self.is_crop_view = is_crop_view
        if hidden_lines is not None:
            self.hidden_lines = hidden_lines
        if modification_id is not None:
            self.modification_id = modification_id
        if perspective is not None:
            self.perspective = perspective
        if projection_angle is not None:
            self.projection_angle = projection_angle
        if show_threads is not None:
            self.show_threads = show_threads
        if is_partial_section is not None:
            self.is_partial_section = is_partial_section
        if broken_out_point_numbers is not None:
            self.broken_out_point_numbers = broken_out_point_numbers
        if broken_out_end_conditions is not None:
            self.broken_out_end_conditions = broken_out_end_conditions
        if broken_out_b_boxes is not None:
            self.broken_out_b_boxes = broken_out_b_boxes
        if broken_out_b_boxes_map is not None:
            self.broken_out_b_boxes_map = broken_out_b_boxes_map
        if include_surfaces is not None:
            self.include_surfaces = include_surfaces
        if is_surface is not None:
            self.is_surface = is_surface
        if depth_section_end_condition is not None:
            self.depth_section_end_condition = depth_section_end_condition
        if display_state_id is not None:
            self.display_state_id = display_state_id
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if parent_change_id is not None:
            self.parent_change_id = parent_change_id
        if model_reference_id is not None:
            self.model_reference_id = model_reference_id
        if view_matrix is not None:
            self.view_matrix = view_matrix
        if view_direction is not None:
            self.view_direction = view_direction
        if cut_point is not None:
            self.cut_point = cut_point
        if offset_section_points is not None:
            self.offset_section_points = offset_section_points
        if broken_out_section is not None:
            self.broken_out_section = broken_out_section
        if bom_reference_id is not None:
            self.bom_reference_id = bom_reference_id
        if occurrence_or_part_id_to_geometry_properties is not None:
            self.occurrence_or_part_id_to_geometry_properties = occurrence_or_part_id_to_geometry_properties

    @property
    def parameters(self):
        """Gets the parameters of this BTAppViewParams.  # noqa: E501


        :return: The parameters of this BTAppViewParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this BTAppViewParams.


        :param parameters: The parameters of this BTAppViewParams.  # noqa: E501
        :type: list[float]
        """

        self._parameters = parameters

    @property
    def crop_view(self):
        """Gets the crop_view of this BTAppViewParams.  # noqa: E501


        :return: The crop_view of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._crop_view

    @crop_view.setter
    def crop_view(self, crop_view):
        """Sets the crop_view of this BTAppViewParams.


        :param crop_view: The crop_view of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._crop_view = crop_view

    @property
    def include_hidden_instances(self):
        """Gets the include_hidden_instances of this BTAppViewParams.  # noqa: E501


        :return: The include_hidden_instances of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_hidden_instances

    @include_hidden_instances.setter
    def include_hidden_instances(self, include_hidden_instances):
        """Sets the include_hidden_instances of this BTAppViewParams.


        :param include_hidden_instances: The include_hidden_instances of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._include_hidden_instances = include_hidden_instances

    @property
    def view_scale(self):
        """Gets the view_scale of this BTAppViewParams.  # noqa: E501


        :return: The view_scale of this BTAppViewParams.  # noqa: E501
        :rtype: float
        """
        return self._view_scale

    @view_scale.setter
    def view_scale(self, view_scale):
        """Sets the view_scale of this BTAppViewParams.


        :param view_scale: The view_scale of this BTAppViewParams.  # noqa: E501
        :type: float
        """

        self._view_scale = view_scale

    @property
    def show_tangent_lines(self):
        """Gets the show_tangent_lines of this BTAppViewParams.  # noqa: E501


        :return: The show_tangent_lines of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_tangent_lines

    @show_tangent_lines.setter
    def show_tangent_lines(self, show_tangent_lines):
        """Sets the show_tangent_lines of this BTAppViewParams.


        :param show_tangent_lines: The show_tangent_lines of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._show_tangent_lines = show_tangent_lines

    @property
    def compute_intersection(self):
        """Gets the compute_intersection of this BTAppViewParams.  # noqa: E501


        :return: The compute_intersection of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._compute_intersection

    @compute_intersection.setter
    def compute_intersection(self, compute_intersection):
        """Sets the compute_intersection of this BTAppViewParams.


        :param compute_intersection: The compute_intersection of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._compute_intersection = compute_intersection

    @property
    def is_broken_out_section(self):
        """Gets the is_broken_out_section of this BTAppViewParams.  # noqa: E501


        :return: The is_broken_out_section of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_broken_out_section

    @is_broken_out_section.setter
    def is_broken_out_section(self, is_broken_out_section):
        """Sets the is_broken_out_section of this BTAppViewParams.


        :param is_broken_out_section: The is_broken_out_section of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._is_broken_out_section = is_broken_out_section

    @property
    def is_crop_view(self):
        """Gets the is_crop_view of this BTAppViewParams.  # noqa: E501


        :return: The is_crop_view of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_crop_view

    @is_crop_view.setter
    def is_crop_view(self, is_crop_view):
        """Sets the is_crop_view of this BTAppViewParams.


        :param is_crop_view: The is_crop_view of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._is_crop_view = is_crop_view

    @property
    def hidden_lines(self):
        """Gets the hidden_lines of this BTAppViewParams.  # noqa: E501


        :return: The hidden_lines of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._hidden_lines

    @hidden_lines.setter
    def hidden_lines(self, hidden_lines):
        """Sets the hidden_lines of this BTAppViewParams.


        :param hidden_lines: The hidden_lines of this BTAppViewParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["DRAFTING", "EXCLUDED", "MARKED"]  # noqa: E501
        if hidden_lines not in allowed_values:
            raise ValueError(
                "Invalid value for `hidden_lines` ({0}), must be one of {1}"  # noqa: E501
                .format(hidden_lines, allowed_values)
            )

        self._hidden_lines = hidden_lines

    @property
    def modification_id(self):
        """Gets the modification_id of this BTAppViewParams.  # noqa: E501


        :return: The modification_id of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._modification_id

    @modification_id.setter
    def modification_id(self, modification_id):
        """Sets the modification_id of this BTAppViewParams.


        :param modification_id: The modification_id of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._modification_id = modification_id

    @property
    def perspective(self):
        """Gets the perspective of this BTAppViewParams.  # noqa: E501


        :return: The perspective of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._perspective

    @perspective.setter
    def perspective(self, perspective):
        """Sets the perspective of this BTAppViewParams.


        :param perspective: The perspective of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._perspective = perspective

    @property
    def projection_angle(self):
        """Gets the projection_angle of this BTAppViewParams.  # noqa: E501


        :return: The projection_angle of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._projection_angle

    @projection_angle.setter
    def projection_angle(self, projection_angle):
        """Sets the projection_angle of this BTAppViewParams.


        :param projection_angle: The projection_angle of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._projection_angle = projection_angle

    @property
    def show_threads(self):
        """Gets the show_threads of this BTAppViewParams.  # noqa: E501


        :return: The show_threads of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_threads

    @show_threads.setter
    def show_threads(self, show_threads):
        """Sets the show_threads of this BTAppViewParams.


        :param show_threads: The show_threads of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._show_threads = show_threads

    @property
    def is_partial_section(self):
        """Gets the is_partial_section of this BTAppViewParams.  # noqa: E501


        :return: The is_partial_section of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_partial_section

    @is_partial_section.setter
    def is_partial_section(self, is_partial_section):
        """Sets the is_partial_section of this BTAppViewParams.


        :param is_partial_section: The is_partial_section of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._is_partial_section = is_partial_section

    @property
    def broken_out_point_numbers(self):
        """Gets the broken_out_point_numbers of this BTAppViewParams.  # noqa: E501


        :return: The broken_out_point_numbers of this BTAppViewParams.  # noqa: E501
        :rtype: list[int]
        """
        return self._broken_out_point_numbers

    @broken_out_point_numbers.setter
    def broken_out_point_numbers(self, broken_out_point_numbers):
        """Sets the broken_out_point_numbers of this BTAppViewParams.


        :param broken_out_point_numbers: The broken_out_point_numbers of this BTAppViewParams.  # noqa: E501
        :type: list[int]
        """

        self._broken_out_point_numbers = broken_out_point_numbers

    @property
    def broken_out_end_conditions(self):
        """Gets the broken_out_end_conditions of this BTAppViewParams.  # noqa: E501


        :return: The broken_out_end_conditions of this BTAppViewParams.  # noqa: E501
        :rtype: dict(str, BTBrokenOutEndCondition)
        """
        return self._broken_out_end_conditions

    @broken_out_end_conditions.setter
    def broken_out_end_conditions(self, broken_out_end_conditions):
        """Sets the broken_out_end_conditions of this BTAppViewParams.


        :param broken_out_end_conditions: The broken_out_end_conditions of this BTAppViewParams.  # noqa: E501
        :type: dict(str, BTBrokenOutEndCondition)
        """

        self._broken_out_end_conditions = broken_out_end_conditions

    @property
    def broken_out_b_boxes(self):
        """Gets the broken_out_b_boxes of this BTAppViewParams.  # noqa: E501


        :return: The broken_out_b_boxes of this BTAppViewParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._broken_out_b_boxes

    @broken_out_b_boxes.setter
    def broken_out_b_boxes(self, broken_out_b_boxes):
        """Sets the broken_out_b_boxes of this BTAppViewParams.


        :param broken_out_b_boxes: The broken_out_b_boxes of this BTAppViewParams.  # noqa: E501
        :type: list[float]
        """

        self._broken_out_b_boxes = broken_out_b_boxes

    @property
    def broken_out_b_boxes_map(self):
        """Gets the broken_out_b_boxes_map of this BTAppViewParams.  # noqa: E501


        :return: The broken_out_b_boxes_map of this BTAppViewParams.  # noqa: E501
        :rtype: dict(str, BTBoundingBox)
        """
        return self._broken_out_b_boxes_map

    @broken_out_b_boxes_map.setter
    def broken_out_b_boxes_map(self, broken_out_b_boxes_map):
        """Sets the broken_out_b_boxes_map of this BTAppViewParams.


        :param broken_out_b_boxes_map: The broken_out_b_boxes_map of this BTAppViewParams.  # noqa: E501
        :type: dict(str, BTBoundingBox)
        """

        self._broken_out_b_boxes_map = broken_out_b_boxes_map

    @property
    def include_surfaces(self):
        """Gets the include_surfaces of this BTAppViewParams.  # noqa: E501


        :return: The include_surfaces of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_surfaces

    @include_surfaces.setter
    def include_surfaces(self, include_surfaces):
        """Sets the include_surfaces of this BTAppViewParams.


        :param include_surfaces: The include_surfaces of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._include_surfaces = include_surfaces

    @property
    def is_surface(self):
        """Gets the is_surface of this BTAppViewParams.  # noqa: E501


        :return: The is_surface of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_surface

    @is_surface.setter
    def is_surface(self, is_surface):
        """Sets the is_surface of this BTAppViewParams.


        :param is_surface: The is_surface of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._is_surface = is_surface

    @property
    def depth_section_end_condition(self):
        """Gets the depth_section_end_condition of this BTAppViewParams.  # noqa: E501


        :return: The depth_section_end_condition of this BTAppViewParams.  # noqa: E501
        :rtype: BTBrokenOutEndCondition
        """
        return self._depth_section_end_condition

    @depth_section_end_condition.setter
    def depth_section_end_condition(self, depth_section_end_condition):
        """Sets the depth_section_end_condition of this BTAppViewParams.


        :param depth_section_end_condition: The depth_section_end_condition of this BTAppViewParams.  # noqa: E501
        :type: BTBrokenOutEndCondition
        """

        self._depth_section_end_condition = depth_section_end_condition

    @property
    def display_state_id(self):
        """Gets the display_state_id of this BTAppViewParams.  # noqa: E501


        :return: The display_state_id of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._display_state_id

    @display_state_id.setter
    def display_state_id(self, display_state_id):
        """Sets the display_state_id of this BTAppViewParams.


        :param display_state_id: The display_state_id of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._display_state_id = display_state_id

    @property
    def transaction_id(self):
        """Gets the transaction_id of this BTAppViewParams.  # noqa: E501


        :return: The transaction_id of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this BTAppViewParams.


        :param transaction_id: The transaction_id of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def parent_change_id(self):
        """Gets the parent_change_id of this BTAppViewParams.  # noqa: E501


        :return: The parent_change_id of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_change_id

    @parent_change_id.setter
    def parent_change_id(self, parent_change_id):
        """Sets the parent_change_id of this BTAppViewParams.


        :param parent_change_id: The parent_change_id of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._parent_change_id = parent_change_id

    @property
    def model_reference_id(self):
        """Gets the model_reference_id of this BTAppViewParams.  # noqa: E501


        :return: The model_reference_id of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._model_reference_id

    @model_reference_id.setter
    def model_reference_id(self, model_reference_id):
        """Sets the model_reference_id of this BTAppViewParams.


        :param model_reference_id: The model_reference_id of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._model_reference_id = model_reference_id

    @property
    def view_matrix(self):
        """Gets the view_matrix of this BTAppViewParams.  # noqa: E501


        :return: The view_matrix of this BTAppViewParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._view_matrix

    @view_matrix.setter
    def view_matrix(self, view_matrix):
        """Sets the view_matrix of this BTAppViewParams.


        :param view_matrix: The view_matrix of this BTAppViewParams.  # noqa: E501
        :type: list[float]
        """

        self._view_matrix = view_matrix

    @property
    def view_direction(self):
        """Gets the view_direction of this BTAppViewParams.  # noqa: E501


        :return: The view_direction of this BTAppViewParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._view_direction

    @view_direction.setter
    def view_direction(self, view_direction):
        """Sets the view_direction of this BTAppViewParams.


        :param view_direction: The view_direction of this BTAppViewParams.  # noqa: E501
        :type: list[float]
        """

        self._view_direction = view_direction

    @property
    def cut_point(self):
        """Gets the cut_point of this BTAppViewParams.  # noqa: E501


        :return: The cut_point of this BTAppViewParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._cut_point

    @cut_point.setter
    def cut_point(self, cut_point):
        """Sets the cut_point of this BTAppViewParams.


        :param cut_point: The cut_point of this BTAppViewParams.  # noqa: E501
        :type: list[float]
        """

        self._cut_point = cut_point

    @property
    def offset_section_points(self):
        """Gets the offset_section_points of this BTAppViewParams.  # noqa: E501


        :return: The offset_section_points of this BTAppViewParams.  # noqa: E501
        :rtype: list[float]
        """
        return self._offset_section_points

    @offset_section_points.setter
    def offset_section_points(self, offset_section_points):
        """Sets the offset_section_points of this BTAppViewParams.


        :param offset_section_points: The offset_section_points of this BTAppViewParams.  # noqa: E501
        :type: list[float]
        """

        self._offset_section_points = offset_section_points

    @property
    def broken_out_section(self):
        """Gets the broken_out_section of this BTAppViewParams.  # noqa: E501


        :return: The broken_out_section of this BTAppViewParams.  # noqa: E501
        :rtype: bool
        """
        return self._broken_out_section

    @broken_out_section.setter
    def broken_out_section(self, broken_out_section):
        """Sets the broken_out_section of this BTAppViewParams.


        :param broken_out_section: The broken_out_section of this BTAppViewParams.  # noqa: E501
        :type: bool
        """

        self._broken_out_section = broken_out_section

    @property
    def bom_reference_id(self):
        """Gets the bom_reference_id of this BTAppViewParams.  # noqa: E501


        :return: The bom_reference_id of this BTAppViewParams.  # noqa: E501
        :rtype: str
        """
        return self._bom_reference_id

    @bom_reference_id.setter
    def bom_reference_id(self, bom_reference_id):
        """Sets the bom_reference_id of this BTAppViewParams.


        :param bom_reference_id: The bom_reference_id of this BTAppViewParams.  # noqa: E501
        :type: str
        """

        self._bom_reference_id = bom_reference_id

    @property
    def occurrence_or_part_id_to_geometry_properties(self):
        """Gets the occurrence_or_part_id_to_geometry_properties of this BTAppViewParams.  # noqa: E501


        :return: The occurrence_or_part_id_to_geometry_properties of this BTAppViewParams.  # noqa: E501
        :rtype: dict(str, dict(str, str))
        """
        return self._occurrence_or_part_id_to_geometry_properties

    @occurrence_or_part_id_to_geometry_properties.setter
    def occurrence_or_part_id_to_geometry_properties(self, occurrence_or_part_id_to_geometry_properties):
        """Sets the occurrence_or_part_id_to_geometry_properties of this BTAppViewParams.


        :param occurrence_or_part_id_to_geometry_properties: The occurrence_or_part_id_to_geometry_properties of this BTAppViewParams.  # noqa: E501
        :type: dict(str, dict(str, str))
        """

        self._occurrence_or_part_id_to_geometry_properties = occurrence_or_part_id_to_geometry_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAppViewParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTReleasePackageItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'state': 'int',
        'element_type': 'int',
        'children': 'list[BTReleasePackageItem]',
        'revision': 'str',
        'microversion_id': 'str',
        'part_number': 'str',
        'mime_type': 'str',
        'configuration': 'str',
        'created_at': 'datetime',
        'company_id': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'configuration_key': 'str',
        'workspace_id': 'str',
        'element_id': 'str',
        'modified_at': 'datetime',
        'document_id': 'str',
        'version_id': 'str',
        'part_id': 'str',
        'small_thumbnail_href': 'str',
        'initial_revision': 'str',
        'is_revision_managed': 'bool',
        'errors': 'list[BTReleasePackageItemError]',
        'diff_thumbnail_configuration_key': 'str',
        'revision_rule_id': 'str',
        'is_included': 'bool',
        'remote_state': 'int',
        'rpid': 'str',
        'obsoletion_revision_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'state': 'state',
        'element_type': 'elementType',
        'children': 'children',
        'revision': 'revision',
        'microversion_id': 'microversionId',
        'part_number': 'partNumber',
        'mime_type': 'mimeType',
        'configuration': 'configuration',
        'created_at': 'createdAt',
        'company_id': 'companyId',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'configuration_key': 'configurationKey',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'modified_at': 'modifiedAt',
        'document_id': 'documentId',
        'version_id': 'versionId',
        'part_id': 'partId',
        'small_thumbnail_href': 'smallThumbnailHref',
        'initial_revision': 'initialRevision',
        'is_revision_managed': 'isRevisionManaged',
        'errors': 'errors',
        'diff_thumbnail_configuration_key': 'diffThumbnailConfigurationKey',
        'revision_rule_id': 'revisionRuleId',
        'is_included': 'isIncluded',
        'remote_state': 'remoteState',
        'rpid': 'rpid',
        'obsoletion_revision_id': 'obsoletionRevisionId'
    }

    def __init__(self, name=None, id=None, state=None, element_type=None, children=None, revision=None, microversion_id=None, part_number=None, mime_type=None, configuration=None, created_at=None, company_id=None, created_by=None, modified_by=None, configuration_key=None, workspace_id=None, element_id=None, modified_at=None, document_id=None, version_id=None, part_id=None, small_thumbnail_href=None, initial_revision=None, is_revision_managed=None, errors=None, diff_thumbnail_configuration_key=None, revision_rule_id=None, is_included=None, remote_state=None, rpid=None, obsoletion_revision_id=None):  # noqa: E501
        """BTReleasePackageItem - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._id = None
        self._state = None
        self._element_type = None
        self._children = None
        self._revision = None
        self._microversion_id = None
        self._part_number = None
        self._mime_type = None
        self._configuration = None
        self._created_at = None
        self._company_id = None
        self._created_by = None
        self._modified_by = None
        self._configuration_key = None
        self._workspace_id = None
        self._element_id = None
        self._modified_at = None
        self._document_id = None
        self._version_id = None
        self._part_id = None
        self._small_thumbnail_href = None
        self._initial_revision = None
        self._is_revision_managed = None
        self._errors = None
        self._diff_thumbnail_configuration_key = None
        self._revision_rule_id = None
        self._is_included = None
        self._remote_state = None
        self._rpid = None
        self._obsoletion_revision_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if state is not None:
            self.state = state
        if element_type is not None:
            self.element_type = element_type
        if children is not None:
            self.children = children
        if revision is not None:
            self.revision = revision
        if microversion_id is not None:
            self.microversion_id = microversion_id
        if part_number is not None:
            self.part_number = part_number
        if mime_type is not None:
            self.mime_type = mime_type
        if configuration is not None:
            self.configuration = configuration
        if created_at is not None:
            self.created_at = created_at
        if company_id is not None:
            self.company_id = company_id
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if configuration_key is not None:
            self.configuration_key = configuration_key
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if modified_at is not None:
            self.modified_at = modified_at
        if document_id is not None:
            self.document_id = document_id
        if version_id is not None:
            self.version_id = version_id
        if part_id is not None:
            self.part_id = part_id
        if small_thumbnail_href is not None:
            self.small_thumbnail_href = small_thumbnail_href
        if initial_revision is not None:
            self.initial_revision = initial_revision
        if is_revision_managed is not None:
            self.is_revision_managed = is_revision_managed
        if errors is not None:
            self.errors = errors
        if diff_thumbnail_configuration_key is not None:
            self.diff_thumbnail_configuration_key = diff_thumbnail_configuration_key
        if revision_rule_id is not None:
            self.revision_rule_id = revision_rule_id
        if is_included is not None:
            self.is_included = is_included
        if remote_state is not None:
            self.remote_state = remote_state
        if rpid is not None:
            self.rpid = rpid
        if obsoletion_revision_id is not None:
            self.obsoletion_revision_id = obsoletion_revision_id

    @property
    def name(self):
        """Gets the name of this BTReleasePackageItem.  # noqa: E501


        :return: The name of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTReleasePackageItem.


        :param name: The name of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTReleasePackageItem.  # noqa: E501


        :return: The id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTReleasePackageItem.


        :param id: The id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def state(self):
        """Gets the state of this BTReleasePackageItem.  # noqa: E501


        :return: The state of this BTReleasePackageItem.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTReleasePackageItem.


        :param state: The state of this BTReleasePackageItem.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def element_type(self):
        """Gets the element_type of this BTReleasePackageItem.  # noqa: E501


        :return: The element_type of this BTReleasePackageItem.  # noqa: E501
        :rtype: int
        """
        return self._element_type

    @element_type.setter
    def element_type(self, element_type):
        """Sets the element_type of this BTReleasePackageItem.


        :param element_type: The element_type of this BTReleasePackageItem.  # noqa: E501
        :type: int
        """

        self._element_type = element_type

    @property
    def children(self):
        """Gets the children of this BTReleasePackageItem.  # noqa: E501


        :return: The children of this BTReleasePackageItem.  # noqa: E501
        :rtype: list[BTReleasePackageItem]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this BTReleasePackageItem.


        :param children: The children of this BTReleasePackageItem.  # noqa: E501
        :type: list[BTReleasePackageItem]
        """

        self._children = children

    @property
    def revision(self):
        """Gets the revision of this BTReleasePackageItem.  # noqa: E501


        :return: The revision of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this BTReleasePackageItem.


        :param revision: The revision of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def microversion_id(self):
        """Gets the microversion_id of this BTReleasePackageItem.  # noqa: E501


        :return: The microversion_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._microversion_id

    @microversion_id.setter
    def microversion_id(self, microversion_id):
        """Sets the microversion_id of this BTReleasePackageItem.


        :param microversion_id: The microversion_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._microversion_id = microversion_id

    @property
    def part_number(self):
        """Gets the part_number of this BTReleasePackageItem.  # noqa: E501


        :return: The part_number of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this BTReleasePackageItem.


        :param part_number: The part_number of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def mime_type(self):
        """Gets the mime_type of this BTReleasePackageItem.  # noqa: E501


        :return: The mime_type of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this BTReleasePackageItem.


        :param mime_type: The mime_type of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def configuration(self):
        """Gets the configuration of this BTReleasePackageItem.  # noqa: E501


        :return: The configuration of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTReleasePackageItem.


        :param configuration: The configuration of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def created_at(self):
        """Gets the created_at of this BTReleasePackageItem.  # noqa: E501


        :return: The created_at of this BTReleasePackageItem.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTReleasePackageItem.


        :param created_at: The created_at of this BTReleasePackageItem.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def company_id(self):
        """Gets the company_id of this BTReleasePackageItem.  # noqa: E501


        :return: The company_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this BTReleasePackageItem.


        :param company_id: The company_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    @property
    def created_by(self):
        """Gets the created_by of this BTReleasePackageItem.  # noqa: E501


        :return: The created_by of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTReleasePackageItem.


        :param created_by: The created_by of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this BTReleasePackageItem.  # noqa: E501


        :return: The modified_by of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this BTReleasePackageItem.


        :param modified_by: The modified_by of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def configuration_key(self):
        """Gets the configuration_key of this BTReleasePackageItem.  # noqa: E501


        :return: The configuration_key of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._configuration_key

    @configuration_key.setter
    def configuration_key(self, configuration_key):
        """Sets the configuration_key of this BTReleasePackageItem.


        :param configuration_key: The configuration_key of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._configuration_key = configuration_key

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTReleasePackageItem.  # noqa: E501


        :return: The workspace_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTReleasePackageItem.


        :param workspace_id: The workspace_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTReleasePackageItem.  # noqa: E501


        :return: The element_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTReleasePackageItem.


        :param element_id: The element_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def modified_at(self):
        """Gets the modified_at of this BTReleasePackageItem.  # noqa: E501


        :return: The modified_at of this BTReleasePackageItem.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTReleasePackageItem.


        :param modified_at: The modified_at of this BTReleasePackageItem.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def document_id(self):
        """Gets the document_id of this BTReleasePackageItem.  # noqa: E501


        :return: The document_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTReleasePackageItem.


        :param document_id: The document_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def version_id(self):
        """Gets the version_id of this BTReleasePackageItem.  # noqa: E501


        :return: The version_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTReleasePackageItem.


        :param version_id: The version_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    @property
    def part_id(self):
        """Gets the part_id of this BTReleasePackageItem.  # noqa: E501


        :return: The part_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTReleasePackageItem.


        :param part_id: The part_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def small_thumbnail_href(self):
        """Gets the small_thumbnail_href of this BTReleasePackageItem.  # noqa: E501


        :return: The small_thumbnail_href of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._small_thumbnail_href

    @small_thumbnail_href.setter
    def small_thumbnail_href(self, small_thumbnail_href):
        """Sets the small_thumbnail_href of this BTReleasePackageItem.


        :param small_thumbnail_href: The small_thumbnail_href of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._small_thumbnail_href = small_thumbnail_href

    @property
    def initial_revision(self):
        """Gets the initial_revision of this BTReleasePackageItem.  # noqa: E501


        :return: The initial_revision of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._initial_revision

    @initial_revision.setter
    def initial_revision(self, initial_revision):
        """Sets the initial_revision of this BTReleasePackageItem.


        :param initial_revision: The initial_revision of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._initial_revision = initial_revision

    @property
    def is_revision_managed(self):
        """Gets the is_revision_managed of this BTReleasePackageItem.  # noqa: E501


        :return: The is_revision_managed of this BTReleasePackageItem.  # noqa: E501
        :rtype: bool
        """
        return self._is_revision_managed

    @is_revision_managed.setter
    def is_revision_managed(self, is_revision_managed):
        """Sets the is_revision_managed of this BTReleasePackageItem.


        :param is_revision_managed: The is_revision_managed of this BTReleasePackageItem.  # noqa: E501
        :type: bool
        """

        self._is_revision_managed = is_revision_managed

    @property
    def errors(self):
        """Gets the errors of this BTReleasePackageItem.  # noqa: E501


        :return: The errors of this BTReleasePackageItem.  # noqa: E501
        :rtype: list[BTReleasePackageItemError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BTReleasePackageItem.


        :param errors: The errors of this BTReleasePackageItem.  # noqa: E501
        :type: list[BTReleasePackageItemError]
        """

        self._errors = errors

    @property
    def diff_thumbnail_configuration_key(self):
        """Gets the diff_thumbnail_configuration_key of this BTReleasePackageItem.  # noqa: E501


        :return: The diff_thumbnail_configuration_key of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._diff_thumbnail_configuration_key

    @diff_thumbnail_configuration_key.setter
    def diff_thumbnail_configuration_key(self, diff_thumbnail_configuration_key):
        """Sets the diff_thumbnail_configuration_key of this BTReleasePackageItem.


        :param diff_thumbnail_configuration_key: The diff_thumbnail_configuration_key of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._diff_thumbnail_configuration_key = diff_thumbnail_configuration_key

    @property
    def revision_rule_id(self):
        """Gets the revision_rule_id of this BTReleasePackageItem.  # noqa: E501


        :return: The revision_rule_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._revision_rule_id

    @revision_rule_id.setter
    def revision_rule_id(self, revision_rule_id):
        """Sets the revision_rule_id of this BTReleasePackageItem.


        :param revision_rule_id: The revision_rule_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._revision_rule_id = revision_rule_id

    @property
    def is_included(self):
        """Gets the is_included of this BTReleasePackageItem.  # noqa: E501


        :return: The is_included of this BTReleasePackageItem.  # noqa: E501
        :rtype: bool
        """
        return self._is_included

    @is_included.setter
    def is_included(self, is_included):
        """Sets the is_included of this BTReleasePackageItem.


        :param is_included: The is_included of this BTReleasePackageItem.  # noqa: E501
        :type: bool
        """

        self._is_included = is_included

    @property
    def remote_state(self):
        """Gets the remote_state of this BTReleasePackageItem.  # noqa: E501


        :return: The remote_state of this BTReleasePackageItem.  # noqa: E501
        :rtype: int
        """
        return self._remote_state

    @remote_state.setter
    def remote_state(self, remote_state):
        """Sets the remote_state of this BTReleasePackageItem.


        :param remote_state: The remote_state of this BTReleasePackageItem.  # noqa: E501
        :type: int
        """

        self._remote_state = remote_state

    @property
    def rpid(self):
        """Gets the rpid of this BTReleasePackageItem.  # noqa: E501


        :return: The rpid of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._rpid

    @rpid.setter
    def rpid(self, rpid):
        """Sets the rpid of this BTReleasePackageItem.


        :param rpid: The rpid of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._rpid = rpid

    @property
    def obsoletion_revision_id(self):
        """Gets the obsoletion_revision_id of this BTReleasePackageItem.  # noqa: E501


        :return: The obsoletion_revision_id of this BTReleasePackageItem.  # noqa: E501
        :rtype: str
        """
        return self._obsoletion_revision_id

    @obsoletion_revision_id.setter
    def obsoletion_revision_id(self, obsoletion_revision_id):
        """Sets the obsoletion_revision_id of this BTReleasePackageItem.


        :param obsoletion_revision_id: The obsoletion_revision_id of this BTReleasePackageItem.  # noqa: E501
        :type: str
        """

        self._obsoletion_revision_id = obsoletion_revision_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTReleasePackageItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Card(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'account': 'str',
        'customer': 'str',
        'metadata': 'dict(str, str)',
        'address_city': 'str',
        'address_country': 'str',
        'address_line1': 'str',
        'address_line1_check': 'str',
        'address_line2': 'str',
        'address_state': 'str',
        'address_zip': 'str',
        'address_zip_check': 'str',
        'available_payout_methods': 'list[str]',
        'brand': 'str',
        'country': 'str',
        'currency': 'str',
        'cvc_check': 'str',
        'default_for_currency': 'bool',
        'dynamic_last4': 'str',
        'exp_month': 'int',
        'exp_year': 'int',
        'fingerprint': 'str',
        'funding': 'str',
        'last4': 'str',
        'name': 'str',
        'recipient': 'str',
        'status': 'str',
        'three_d_secure': 'ThreeDSecure',
        'tokenization_method': 'str',
        'description': 'str',
        'iin': 'str',
        'issuer': 'str',
        'type': 'str',
        'instance_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'account': 'account',
        'customer': 'customer',
        'metadata': 'metadata',
        'address_city': 'addressCity',
        'address_country': 'addressCountry',
        'address_line1': 'addressLine1',
        'address_line1_check': 'addressLine1Check',
        'address_line2': 'addressLine2',
        'address_state': 'addressState',
        'address_zip': 'addressZip',
        'address_zip_check': 'addressZipCheck',
        'available_payout_methods': 'availablePayoutMethods',
        'brand': 'brand',
        'country': 'country',
        'currency': 'currency',
        'cvc_check': 'cvcCheck',
        'default_for_currency': 'defaultForCurrency',
        'dynamic_last4': 'dynamicLast4',
        'exp_month': 'expMonth',
        'exp_year': 'expYear',
        'fingerprint': 'fingerprint',
        'funding': 'funding',
        'last4': 'last4',
        'name': 'name',
        'recipient': 'recipient',
        'status': 'status',
        'three_d_secure': 'threeDSecure',
        'tokenization_method': 'tokenizationMethod',
        'description': 'description',
        'iin': 'iin',
        'issuer': 'issuer',
        'type': 'type',
        'instance_url': 'instanceURL'
    }

    def __init__(self, id=None, object=None, account=None, customer=None, metadata=None, address_city=None, address_country=None, address_line1=None, address_line1_check=None, address_line2=None, address_state=None, address_zip=None, address_zip_check=None, available_payout_methods=None, brand=None, country=None, currency=None, cvc_check=None, default_for_currency=None, dynamic_last4=None, exp_month=None, exp_year=None, fingerprint=None, funding=None, last4=None, name=None, recipient=None, status=None, three_d_secure=None, tokenization_method=None, description=None, iin=None, issuer=None, type=None, instance_url=None):  # noqa: E501
        """Card - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._account = None
        self._customer = None
        self._metadata = None
        self._address_city = None
        self._address_country = None
        self._address_line1 = None
        self._address_line1_check = None
        self._address_line2 = None
        self._address_state = None
        self._address_zip = None
        self._address_zip_check = None
        self._available_payout_methods = None
        self._brand = None
        self._country = None
        self._currency = None
        self._cvc_check = None
        self._default_for_currency = None
        self._dynamic_last4 = None
        self._exp_month = None
        self._exp_year = None
        self._fingerprint = None
        self._funding = None
        self._last4 = None
        self._name = None
        self._recipient = None
        self._status = None
        self._three_d_secure = None
        self._tokenization_method = None
        self._description = None
        self._iin = None
        self._issuer = None
        self._type = None
        self._instance_url = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if account is not None:
            self.account = account
        if customer is not None:
            self.customer = customer
        if metadata is not None:
            self.metadata = metadata
        if address_city is not None:
            self.address_city = address_city
        if address_country is not None:
            self.address_country = address_country
        if address_line1 is not None:
            self.address_line1 = address_line1
        if address_line1_check is not None:
            self.address_line1_check = address_line1_check
        if address_line2 is not None:
            self.address_line2 = address_line2
        if address_state is not None:
            self.address_state = address_state
        if address_zip is not None:
            self.address_zip = address_zip
        if address_zip_check is not None:
            self.address_zip_check = address_zip_check
        if available_payout_methods is not None:
            self.available_payout_methods = available_payout_methods
        if brand is not None:
            self.brand = brand
        if country is not None:
            self.country = country
        if currency is not None:
            self.currency = currency
        if cvc_check is not None:
            self.cvc_check = cvc_check
        if default_for_currency is not None:
            self.default_for_currency = default_for_currency
        if dynamic_last4 is not None:
            self.dynamic_last4 = dynamic_last4
        if exp_month is not None:
            self.exp_month = exp_month
        if exp_year is not None:
            self.exp_year = exp_year
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if funding is not None:
            self.funding = funding
        if last4 is not None:
            self.last4 = last4
        if name is not None:
            self.name = name
        if recipient is not None:
            self.recipient = recipient
        if status is not None:
            self.status = status
        if three_d_secure is not None:
            self.three_d_secure = three_d_secure
        if tokenization_method is not None:
            self.tokenization_method = tokenization_method
        if description is not None:
            self.description = description
        if iin is not None:
            self.iin = iin
        if issuer is not None:
            self.issuer = issuer
        if type is not None:
            self.type = type
        if instance_url is not None:
            self.instance_url = instance_url

    @property
    def id(self):
        """Gets the id of this Card.  # noqa: E501


        :return: The id of this Card.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Card.


        :param id: The id of this Card.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this Card.  # noqa: E501


        :return: The object of this Card.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this Card.


        :param object: The object of this Card.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def account(self):
        """Gets the account of this Card.  # noqa: E501


        :return: The account of this Card.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Card.


        :param account: The account of this Card.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def customer(self):
        """Gets the customer of this Card.  # noqa: E501


        :return: The customer of this Card.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this Card.


        :param customer: The customer of this Card.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def metadata(self):
        """Gets the metadata of this Card.  # noqa: E501


        :return: The metadata of this Card.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Card.


        :param metadata: The metadata of this Card.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def address_city(self):
        """Gets the address_city of this Card.  # noqa: E501


        :return: The address_city of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_city

    @address_city.setter
    def address_city(self, address_city):
        """Sets the address_city of this Card.


        :param address_city: The address_city of this Card.  # noqa: E501
        :type: str
        """

        self._address_city = address_city

    @property
    def address_country(self):
        """Gets the address_country of this Card.  # noqa: E501


        :return: The address_country of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_country

    @address_country.setter
    def address_country(self, address_country):
        """Sets the address_country of this Card.


        :param address_country: The address_country of this Card.  # noqa: E501
        :type: str
        """

        self._address_country = address_country

    @property
    def address_line1(self):
        """Gets the address_line1 of this Card.  # noqa: E501


        :return: The address_line1 of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this Card.


        :param address_line1: The address_line1 of this Card.  # noqa: E501
        :type: str
        """

        self._address_line1 = address_line1

    @property
    def address_line1_check(self):
        """Gets the address_line1_check of this Card.  # noqa: E501


        :return: The address_line1_check of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_line1_check

    @address_line1_check.setter
    def address_line1_check(self, address_line1_check):
        """Sets the address_line1_check of this Card.


        :param address_line1_check: The address_line1_check of this Card.  # noqa: E501
        :type: str
        """

        self._address_line1_check = address_line1_check

    @property
    def address_line2(self):
        """Gets the address_line2 of this Card.  # noqa: E501


        :return: The address_line2 of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this Card.


        :param address_line2: The address_line2 of this Card.  # noqa: E501
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def address_state(self):
        """Gets the address_state of this Card.  # noqa: E501


        :return: The address_state of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_state

    @address_state.setter
    def address_state(self, address_state):
        """Sets the address_state of this Card.


        :param address_state: The address_state of this Card.  # noqa: E501
        :type: str
        """

        self._address_state = address_state

    @property
    def address_zip(self):
        """Gets the address_zip of this Card.  # noqa: E501


        :return: The address_zip of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_zip

    @address_zip.setter
    def address_zip(self, address_zip):
        """Sets the address_zip of this Card.


        :param address_zip: The address_zip of this Card.  # noqa: E501
        :type: str
        """

        self._address_zip = address_zip

    @property
    def address_zip_check(self):
        """Gets the address_zip_check of this Card.  # noqa: E501


        :return: The address_zip_check of this Card.  # noqa: E501
        :rtype: str
        """
        return self._address_zip_check

    @address_zip_check.setter
    def address_zip_check(self, address_zip_check):
        """Sets the address_zip_check of this Card.


        :param address_zip_check: The address_zip_check of this Card.  # noqa: E501
        :type: str
        """

        self._address_zip_check = address_zip_check

    @property
    def available_payout_methods(self):
        """Gets the available_payout_methods of this Card.  # noqa: E501


        :return: The available_payout_methods of this Card.  # noqa: E501
        :rtype: list[str]
        """
        return self._available_payout_methods

    @available_payout_methods.setter
    def available_payout_methods(self, available_payout_methods):
        """Sets the available_payout_methods of this Card.


        :param available_payout_methods: The available_payout_methods of this Card.  # noqa: E501
        :type: list[str]
        """

        self._available_payout_methods = available_payout_methods

    @property
    def brand(self):
        """Gets the brand of this Card.  # noqa: E501


        :return: The brand of this Card.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this Card.


        :param brand: The brand of this Card.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def country(self):
        """Gets the country of this Card.  # noqa: E501


        :return: The country of this Card.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Card.


        :param country: The country of this Card.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def currency(self):
        """Gets the currency of this Card.  # noqa: E501


        :return: The currency of this Card.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Card.


        :param currency: The currency of this Card.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def cvc_check(self):
        """Gets the cvc_check of this Card.  # noqa: E501


        :return: The cvc_check of this Card.  # noqa: E501
        :rtype: str
        """
        return self._cvc_check

    @cvc_check.setter
    def cvc_check(self, cvc_check):
        """Sets the cvc_check of this Card.


        :param cvc_check: The cvc_check of this Card.  # noqa: E501
        :type: str
        """

        self._cvc_check = cvc_check

    @property
    def default_for_currency(self):
        """Gets the default_for_currency of this Card.  # noqa: E501


        :return: The default_for_currency of this Card.  # noqa: E501
        :rtype: bool
        """
        return self._default_for_currency

    @default_for_currency.setter
    def default_for_currency(self, default_for_currency):
        """Sets the default_for_currency of this Card.


        :param default_for_currency: The default_for_currency of this Card.  # noqa: E501
        :type: bool
        """

        self._default_for_currency = default_for_currency

    @property
    def dynamic_last4(self):
        """Gets the dynamic_last4 of this Card.  # noqa: E501


        :return: The dynamic_last4 of this Card.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_last4

    @dynamic_last4.setter
    def dynamic_last4(self, dynamic_last4):
        """Sets the dynamic_last4 of this Card.


        :param dynamic_last4: The dynamic_last4 of this Card.  # noqa: E501
        :type: str
        """

        self._dynamic_last4 = dynamic_last4

    @property
    def exp_month(self):
        """Gets the exp_month of this Card.  # noqa: E501


        :return: The exp_month of this Card.  # noqa: E501
        :rtype: int
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """Sets the exp_month of this Card.


        :param exp_month: The exp_month of this Card.  # noqa: E501
        :type: int
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """Gets the exp_year of this Card.  # noqa: E501


        :return: The exp_year of this Card.  # noqa: E501
        :rtype: int
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """Sets the exp_year of this Card.


        :param exp_year: The exp_year of this Card.  # noqa: E501
        :type: int
        """

        self._exp_year = exp_year

    @property
    def fingerprint(self):
        """Gets the fingerprint of this Card.  # noqa: E501


        :return: The fingerprint of this Card.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this Card.


        :param fingerprint: The fingerprint of this Card.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def funding(self):
        """Gets the funding of this Card.  # noqa: E501


        :return: The funding of this Card.  # noqa: E501
        :rtype: str
        """
        return self._funding

    @funding.setter
    def funding(self, funding):
        """Sets the funding of this Card.


        :param funding: The funding of this Card.  # noqa: E501
        :type: str
        """

        self._funding = funding

    @property
    def last4(self):
        """Gets the last4 of this Card.  # noqa: E501


        :return: The last4 of this Card.  # noqa: E501
        :rtype: str
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """Sets the last4 of this Card.


        :param last4: The last4 of this Card.  # noqa: E501
        :type: str
        """

        self._last4 = last4

    @property
    def name(self):
        """Gets the name of this Card.  # noqa: E501


        :return: The name of this Card.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Card.


        :param name: The name of this Card.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def recipient(self):
        """Gets the recipient of this Card.  # noqa: E501


        :return: The recipient of this Card.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this Card.


        :param recipient: The recipient of this Card.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def status(self):
        """Gets the status of this Card.  # noqa: E501


        :return: The status of this Card.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Card.


        :param status: The status of this Card.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def three_d_secure(self):
        """Gets the three_d_secure of this Card.  # noqa: E501


        :return: The three_d_secure of this Card.  # noqa: E501
        :rtype: ThreeDSecure
        """
        return self._three_d_secure

    @three_d_secure.setter
    def three_d_secure(self, three_d_secure):
        """Sets the three_d_secure of this Card.


        :param three_d_secure: The three_d_secure of this Card.  # noqa: E501
        :type: ThreeDSecure
        """

        self._three_d_secure = three_d_secure

    @property
    def tokenization_method(self):
        """Gets the tokenization_method of this Card.  # noqa: E501


        :return: The tokenization_method of this Card.  # noqa: E501
        :rtype: str
        """
        return self._tokenization_method

    @tokenization_method.setter
    def tokenization_method(self, tokenization_method):
        """Sets the tokenization_method of this Card.


        :param tokenization_method: The tokenization_method of this Card.  # noqa: E501
        :type: str
        """

        self._tokenization_method = tokenization_method

    @property
    def description(self):
        """Gets the description of this Card.  # noqa: E501


        :return: The description of this Card.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Card.


        :param description: The description of this Card.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def iin(self):
        """Gets the iin of this Card.  # noqa: E501


        :return: The iin of this Card.  # noqa: E501
        :rtype: str
        """
        return self._iin

    @iin.setter
    def iin(self, iin):
        """Sets the iin of this Card.


        :param iin: The iin of this Card.  # noqa: E501
        :type: str
        """

        self._iin = iin

    @property
    def issuer(self):
        """Gets the issuer of this Card.  # noqa: E501


        :return: The issuer of this Card.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this Card.


        :param issuer: The issuer of this Card.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def type(self):
        """Gets the type of this Card.  # noqa: E501


        :return: The type of this Card.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Card.


        :param type: The type of this Card.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def instance_url(self):
        """Gets the instance_url of this Card.  # noqa: E501


        :return: The instance_url of this Card.  # noqa: E501
        :rtype: str
        """
        return self._instance_url

    @instance_url.setter
    def instance_url(self, instance_url):
        """Sets the instance_url of this Card.


        :param instance_url: The instance_url of this Card.  # noqa: E501
        :type: str
        """

        self._instance_url = instance_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Card):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentSearchParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'raw_query': 'str',
        'offset': 'int',
        'limit': 'int',
        'owner_id': 'str',
        'parent_id': 'str',
        'document_filter': 'int',
        'sort_column': 'str',
        'sort_order': 'str',
        'found_in': 'str',
        'when': 'str'
    }

    attribute_map = {
        'type': 'type',
        'raw_query': 'rawQuery',
        'offset': 'offset',
        'limit': 'limit',
        'owner_id': 'ownerId',
        'parent_id': 'parentId',
        'document_filter': 'documentFilter',
        'sort_column': 'sortColumn',
        'sort_order': 'sortOrder',
        'found_in': 'foundIn',
        'when': 'when'
    }

    def __init__(self, type=None, raw_query=None, offset=None, limit=None, owner_id=None, parent_id=None, document_filter=None, sort_column=None, sort_order=None, found_in=None, when=None):  # noqa: E501
        """BTDocumentSearchParams - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._raw_query = None
        self._offset = None
        self._limit = None
        self._owner_id = None
        self._parent_id = None
        self._document_filter = None
        self._sort_column = None
        self._sort_order = None
        self._found_in = None
        self._when = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if raw_query is not None:
            self.raw_query = raw_query
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if owner_id is not None:
            self.owner_id = owner_id
        if parent_id is not None:
            self.parent_id = parent_id
        if document_filter is not None:
            self.document_filter = document_filter
        if sort_column is not None:
            self.sort_column = sort_column
        if sort_order is not None:
            self.sort_order = sort_order
        if found_in is not None:
            self.found_in = found_in
        if when is not None:
            self.when = when

    @property
    def type(self):
        """Gets the type of this BTDocumentSearchParams.  # noqa: E501


        :return: The type of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTDocumentSearchParams.


        :param type: The type of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def raw_query(self):
        """Gets the raw_query of this BTDocumentSearchParams.  # noqa: E501


        :return: The raw_query of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._raw_query

    @raw_query.setter
    def raw_query(self, raw_query):
        """Sets the raw_query of this BTDocumentSearchParams.


        :param raw_query: The raw_query of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """

        self._raw_query = raw_query

    @property
    def offset(self):
        """Gets the offset of this BTDocumentSearchParams.  # noqa: E501


        :return: The offset of this BTDocumentSearchParams.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this BTDocumentSearchParams.


        :param offset: The offset of this BTDocumentSearchParams.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this BTDocumentSearchParams.  # noqa: E501


        :return: The limit of this BTDocumentSearchParams.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this BTDocumentSearchParams.


        :param limit: The limit of this BTDocumentSearchParams.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def owner_id(self):
        """Gets the owner_id of this BTDocumentSearchParams.  # noqa: E501


        :return: The owner_id of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTDocumentSearchParams.


        :param owner_id: The owner_id of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def parent_id(self):
        """Gets the parent_id of this BTDocumentSearchParams.  # noqa: E501


        :return: The parent_id of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTDocumentSearchParams.


        :param parent_id: The parent_id of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def document_filter(self):
        """Gets the document_filter of this BTDocumentSearchParams.  # noqa: E501


        :return: The document_filter of this BTDocumentSearchParams.  # noqa: E501
        :rtype: int
        """
        return self._document_filter

    @document_filter.setter
    def document_filter(self, document_filter):
        """Sets the document_filter of this BTDocumentSearchParams.


        :param document_filter: The document_filter of this BTDocumentSearchParams.  # noqa: E501
        :type: int
        """

        self._document_filter = document_filter

    @property
    def sort_column(self):
        """Gets the sort_column of this BTDocumentSearchParams.  # noqa: E501


        :return: The sort_column of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._sort_column

    @sort_column.setter
    def sort_column(self, sort_column):
        """Sets the sort_column of this BTDocumentSearchParams.


        :param sort_column: The sort_column of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """

        self._sort_column = sort_column

    @property
    def sort_order(self):
        """Gets the sort_order of this BTDocumentSearchParams.  # noqa: E501


        :return: The sort_order of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this BTDocumentSearchParams.


        :param sort_order: The sort_order of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """

        self._sort_order = sort_order

    @property
    def found_in(self):
        """Gets the found_in of this BTDocumentSearchParams.  # noqa: E501


        :return: The found_in of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._found_in

    @found_in.setter
    def found_in(self, found_in):
        """Sets the found_in of this BTDocumentSearchParams.


        :param found_in: The found_in of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["ALL", "WORKSPACES", "VERSIONS"]  # noqa: E501
        if found_in not in allowed_values:
            raise ValueError(
                "Invalid value for `found_in` ({0}), must be one of {1}"  # noqa: E501
                .format(found_in, allowed_values)
            )

        self._found_in = found_in

    @property
    def when(self):
        """Gets the when of this BTDocumentSearchParams.  # noqa: E501


        :return: The when of this BTDocumentSearchParams.  # noqa: E501
        :rtype: str
        """
        return self._when

    @when.setter
    def when(self, when):
        """Sets the when of this BTDocumentSearchParams.


        :param when: The when of this BTDocumentSearchParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["ALL", "LATEST", "LATEST_PER_HIT"]  # noqa: E501
        if when not in allowed_values:
            raise ValueError(
                "Invalid value for `when` ({0}), must be one of {1}"  # noqa: E501
                .format(when, allowed_values)
            )

        self._when = when

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentSearchParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
